==> nui_map-0.0.1.tar.gz: lib/nui_map.dart <==
library nui_map;
import 'dart:typed_data';

import 'package:flutter/cupertino.dart';
import 'package:google_maps_cluster_manager/google_maps_cluster_manager.dart';
import 'package:google_maps_flutter/google_maps_flutter.dart';
import 'package:nui_core/nui_core.dart';
import 'package:nui_geolocator/nui_geolocator.dart';

abstract class NUIMapComponent{
  String id;
  LatLng getMapPosition();
}

typedef NUIMapMarkerOnCluster = NUIMapMarker Function(List<NUIMapMarker> clusterItems);

class NUIMapClusterItem extends ClusterItem<NUIMapMarker>{
  NUIMapClusterItem(LatLng location, NUIMapMarker marker) : super(location, item: marker);
}

class NUIMapMarker<T> extends NUIMapComponent{
  NUIMapMarker({String id, this.data, @required this.position, this.label, this.draggable: false, this.anchor: const Offset(0.5, 1.0), this.customMarker, this.customFutureMarker, this.markerStyle : BitmapDescriptor.defaultMarker, this.onClusterListener}){
    this.id = id;
  }

  T data;
  NUILatLng position;
  String label;
  bool draggable;
  Uint8List customMarker;
  Offset anchor;
  Future<Uint8List> customFutureMarker;
  BitmapDescriptor markerStyle;
  NUIMapMarkerOnCluster onClusterListener;

  @override
  LatLng getMapPosition() {
    return LatLng(position.latitude, position.longitude);
  }

  Future<Marker> getClusteredMarker(List<NUIMapMarker> markers, {Function onTap}) async{
    if(onClusterListener != null) {
      final marker = onClusterListener(markers);
      return marker.getMarker(onTap: onTap);
    }
    return null;
  }

  Future<Marker> getMarker({Function onTap}) async{
    Uint8List imageToUse = customMarker;
    if(customFutureMarker != null){
      logNUI("NUIMap", "Custom future marker is found, loading that ...");
      imageToUse = await customFutureMarker;
      logNUI("NUIMap", "Custom future marker loaded successfully");
    }

    return Marker(
        markerId: MarkerId(id ?? randomUUID()),
        position: getMapPosition(),
        anchor: anchor,
        draggable: draggable ?? false,
        onTap: onTap,
        icon: imageToUse != null ? BitmapDescriptor.fromBytes(imageToUse) : (markerStyle ?? BitmapDescriptor.defaultMarker),
        infoWindow: isNullOrEmpty(label) ? null : InfoWindow(title: label),
    );
  }
}

class NUIMapCircle extends NUIMapComponent{
  NUIMapCircle({String id, @required this.position, @required this.radiusInMetre, this.strokeWidth : 0, this.strokeColor, this.fillColor}){
    this.id = id;
  }
  final NUILatLng position;
  final double radiusInMetre;
  final Color fillColor;
  final Color strokeColor;
  final int strokeWidth;
  
  @override
  LatLng getMapPosition() {
    return LatLng(position.latitude, position.longitude);
  }
  
  Circle getCircle(){
    return Circle(
        circleId: CircleId(id ?? randomUUID()),
        center: LatLng(position.latitude, position.longitude),
        radius: radiusInMetre ?? 100,
        strokeColor: strokeColor ?? NUIColors.NUIAccent.withOpacity(0.3),
        fillColor: fillColor ?? NUIColors.NUIAccent.withOpacity(0.3),
        strokeWidth: strokeWidth ?? 0
    );
  }

}

class NUIMapPolygon{

}

class NUIMap {
  static void initialize(){
    NUIGeoLocatorBuilder()
        .build();
  }
}

==> nui_map-0.0.9.tar.gz: lib/nui_map.dart <==
library nui_map;
import 'dart:typed_data';

import 'package:flutter/cupertino.dart';
import 'package:google_maps_cluster_manager/google_maps_cluster_manager.dart';
import 'package:google_maps_flutter/google_maps_flutter.dart';
import 'package:nui_core/nui_core.dart';
import 'package:nui_geolocator/nui_geolocator.dart';

abstract class NUIMapComponent{
  String id;
  LatLng getMapPosition();
}

typedef NUIMapMarkerOnCluster = NUIMapMarker Function(List<NUIMapMarker> clusterItems);

class NUIMapClusterItem extends ClusterItem<NUIMapMarker>{
  NUIMapClusterItem(LatLng location, NUIMapMarker marker) : super(location, item: marker);
}

class NUIMapMarker<T> extends NUIMapComponent{
  NUIMapMarker({String id, this.data, @required this.position, this.label, this.draggable: false, this.anchor: const Offset(0.5, 1.0), this.customMarker, this.customFutureMarker, this.markerStyle : BitmapDescriptor.defaultMarker, this.onClusterListener}){
    this.id = id;
  }

  T data;
  NUILatLng position;
  String label;
  bool draggable;
  Uint8List customMarker;
  Offset anchor;
  Future<Uint8List> customFutureMarker;
  BitmapDescriptor markerStyle;
  NUIMapMarkerOnCluster onClusterListener;

  @override
  LatLng getMapPosition() {
    return LatLng(position.latitude, position.longitude);
  }

  Future<Marker> getClusteredMarker(List<NUIMapMarker> markers, {Function onTap}) async{
    if(onClusterListener != null) {
      final marker = onClusterListener(markers);
      return marker.getMarker(onTap: onTap);
    }
    return null;
  }

  Future<Marker> getMarker({Function onTap}) async{
    Uint8List imageToUse = customMarker;
    if(customFutureMarker != null){
      logNUI("NUIMap", "Custom future marker is found, loading that ...");
      imageToUse = await customFutureMarker;
      logNUI("NUIMap", "Custom future marker loaded successfully");
    }

    return Marker(
        markerId: MarkerId(id ?? randomUUID()),
        position: getMapPosition(),
        anchor: anchor,
        draggable: draggable ?? false,
        onTap: onTap,
        icon: imageToUse != null ? BitmapDescriptor.fromBytes(imageToUse) : (markerStyle ?? BitmapDescriptor.defaultMarker),
        infoWindow: isNullOrEmpty(label) ? null : InfoWindow(title: label),
    );
  }
}

class NUIMapCircle extends NUIMapComponent{
  NUIMapCircle({String id, @required this.position, @required this.radiusInMetre, this.strokeWidth : 0, this.strokeColor, this.fillColor}){
    this.id = id;
  }
  final NUILatLng position;
  final double radiusInMetre;
  final Color fillColor;
  final Color strokeColor;
  final int strokeWidth;
  
  @override
  LatLng getMapPosition() {
    return LatLng(position.latitude, position.longitude);
  }
  
  Circle getCircle(){
    return Circle(
        circleId: CircleId(id ?? randomUUID()),
        center: LatLng(position.latitude, position.longitude),
        radius: radiusInMetre ?? 100,
        strokeColor: strokeColor ?? NUIColors.NUIAccent.withOpacity(0.3),
        fillColor: fillColor ?? NUIColors.NUIAccent.withOpacity(0.3),
        strokeWidth: strokeWidth ?? 0
    );
  }

}

class NUIMapPolyline extends NUIMapComponent{

  NUIMapPolyline({String id, this.points, this.visible, this.width, this.color, this.onTap, this.zIndex, this.geodesic, this.consumeTapEvents}){
    this.id = id;
  }
  final List<NUILatLng> points;
  final bool visible;
  final int width;
  final Color color;
  final int zIndex;
  final bool geodesic;
  final bool consumeTapEvents;
  final Function() onTap;


  @override
  LatLng getMapPosition() {
    return LatLng(points.first.latitude, points.first.longitude);
  }

  List<LatLng> getPolylineLatLng(){
    return points.map((e) => LatLng(e.latitude, e.longitude)).toList();
  }

  Polyline getPolyline(){
    return Polyline(
      polylineId: PolylineId(id ?? randomUUID()),
      visible: visible ?? true,
      color: color ?? NUIColors.NUIAccent,
      width: width ?? 10,
      onTap: onTap ?? null,
      points: getPolylineLatLng() ?? [],
      zIndex: zIndex ?? 0,
      consumeTapEvents: consumeTapEvents ?? false,
      geodesic: geodesic ?? false,
      jointType: JointType.round,
      startCap: Cap.roundCap,
      endCap: Cap.roundCap,
    );
  }
}

class NUIMap {
  static void initialize(){
    NUIGeoLocatorBuilder()
        .build();
  }
}
